# ToolChoiceEnum


## Enum

* `AUTO` (value: `'auto'`)

* `NONE` (value: `'none'`)

* `REQUIRED` (value: `'required'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


